@@ -23,9 +23,10 @@ from typing import (
     Union,
 )
 
+import chardet
 from anyio import create_task_group, move_on_after, open_process
 from anyio.abc import Process
-from anyio.streams.text import TextReceiveStream
+from anyio.streams.buffered import BufferedByteReceiveStream
 
 from .errors import CommandFailedError, CommandNotFoundError
 from .logger import logger
@@ -44,6 +45,7 @@ class Command:
         cmd: Union[str, List[str]],
         shell: Optional[bool] = None,
         cwd: Union[str, Path, None] = None,
+        virtualenv: Union[str, Path, None] = None,
         env: Optional[Mapping[str, str]] = None,
         append_path: Optional[Union[str, Path, List[Union[str, Path]], None]] = None,
         timeout: Optional[float] = None,
@@ -97,14 +99,25 @@ class Command:
         # Make sure append_path is a list (and not a string or a path instance)
         if isinstance(append_path, (str, Path)):
             append_path = [append_path]
+        # Optionally add user provided environment variables
+        if env:
+            environment.update(env)
+        # Update environment to execute command within virtual environment
+        if virtualenv:
+            virtualenv_path = Path(virtualenv)
+            venv_bin = (
+                virtualenv_path / "Scripts" if IS_WINDOWS else virtualenv_path / "bin"
+            )
+            environment.update({"VIRTUAL_ENV": virtualenv_path.as_posix()})
+            if append_path:
+                append_path.append(venv_bin)
+            else:
+                append_path = [venv_bin]
         # Optionally append directories to path environment variable
         if append_path:
             for path in append_path:
                 path = Path(path).resolve(True)
                 environment["PATH"] = ":".join([path.as_posix(), environment["PATH"]])
-        # Optionally add user provided environment variables
-        if env:
-            environment.update(env)
         # Store environment
         self.environment = environment
         # Initialize stdout and stderr which whill be parsed from command
@@ -168,6 +181,8 @@ class Command:
         pid = self.pid
         if pid is None:
             return None
+        if IS_WINDOWS:
+            return None
         return os.getpgid(pid)
 
     @property
@@ -308,25 +323,33 @@ class Command:
 
     def terminate(self) -> None:
         """Terminate command process (send SIGTERM)"""
-        self.send_signal(signal.SIGTERM)
+        if IS_WINDOWS:
+            return self.process.terminate()
+        else:
+            return self.send_signal(signal.SIGTERM)
 
     def kill(self) -> None:
         """Kill command process (send SIGKILL)"""
-        self.send_signal(signal.SIGKILL)
+        if IS_WINDOWS:
+            return self.process.kill()
+        else:
+            return self.send_signal(signal.SIGKILL)
 
     def send_signal(self, _signal: int) -> None:
         """Send signal to command process"""
         valid_signal = signal.Signals(_signal)
+        if IS_WINDOWS:
+            try:
+                return self.process.send_signal(valid_signal)
+            except (ProcessLookupError, FileNotFoundError):
+                return
         pid = self.pid
         if pid is None:
             return
         try:
             if self._start_new_session:
-                if not IS_WINDOWS:
-                    pgid = os.getpgid(pid)
-                    os.killpg(pgid, valid_signal.value)
-                else:
-                    self.process.send_signal(valid_signal)
+                pgid = os.getpgid(pid)
+                os.killpg(pgid, valid_signal.value)
             else:
                 self.process.send_signal(valid_signal)
         except ProcessLookupError:
@@ -334,8 +357,14 @@ class Command:
 
     async def _process_stderr(self) -> None:
         """Process incoming stream of text received from command stderr"""
+        default_encoding = "utf-8"
         if self.process.stderr:
-            async for text in TextReceiveStream(self.process.stderr):
+            async for chunk in BufferedByteReceiveStream(self.process.stderr):
+                try:
+                    text = chunk.decode(default_encoding)
+                except UnicodeDecodeError:
+                    default_encoding = chardet.detect(chunk)["encoding"]
+                    text = chunk.decode(default_encoding)
                 self._stderr_read += text
                 if iscoroutinefunction(self._stderr_sink):
                     await self._stderr_sink(text)  # type: ignore[misc]
@@ -344,8 +373,14 @@ class Command:
 
     async def _process_stdout(self) -> None:
         """Process incoming stream if text received from command stdout"""
+        default_encoding = "utf-8"
         if self.process.stdout:
-            async for text in TextReceiveStream(self.process.stdout):
+            async for chunk in BufferedByteReceiveStream(self.process.stdout):
+                try:
+                    text = chunk.decode(default_encoding)
+                except UnicodeDecodeError:
+                    default_encoding = chardet.detect(chunk)["encoding"]
+                    text = chunk.decode(default_encoding)
                 self._stdout_read += text
                 if iscoroutinefunction(self._stdout_sink):
                     await self._stdout_sink(text)  # type: ignore[misc]
@@ -494,6 +529,7 @@ async def run_command(
     cmd: Union[str, List[str]],
     shell: Optional[bool] = None,
     cwd: Union[str, Path, None] = None,
+    virtualenv: Union[str, Path, None] = None,
     env: Optional[Mapping[str, str]] = None,
     append_path: Optional[Union[str, Path, List[Union[str, Path]], None]] = None,
     timeout: Optional[float] = None,
@@ -519,6 +555,7 @@ async def run_command(
         cmd,
         shell=shell,
         cwd=cwd,
+        virtualenv=virtualenv,
         env=env,
         append_path=append_path,
         timeout=timeout,
@@ -539,6 +576,7 @@ async def check_command(
     cmd: Union[str, List[str]],
     shell: Optional[bool] = None,
     cwd: Union[str, Path, None] = None,
+    virtualenv: Union[str, Path, None] = None,
     env: Optional[Mapping[str, str]] = None,
     append_path: Optional[Union[str, Path, List[Union[str, Path]], None]] = None,
     timeout: Optional[float] = None,
@@ -564,6 +602,7 @@ async def check_command(
         cmd,
         shell=shell,
         cwd=cwd,
+        virtualenv=virtualenv,
         env=env,
         append_path=append_path,
         timeout=timeout,
@@ -584,6 +623,7 @@ async def check_command_stdout(
     cmd: Union[str, List[str]],
     shell: Optional[bool] = None,
     cwd: Union[str, Path, None] = None,
+    virtualenv: Union[str, Path, None] = None,
     env: Optional[Mapping[str, str]] = None,
     append_path: Optional[Union[str, Path, List[Union[str, Path]], None]] = None,
     timeout: Optional[float] = None,
@@ -598,6 +638,7 @@ async def check_command_stdout(
         cmd,
         shell=shell,
         cwd=cwd,
+        virtualenv=virtualenv,
         env=env,
         append_path=append_path,
         timeout=timeout,
@@ -623,6 +664,7 @@ async def check_command_sterr(
     cmd: Union[str, List[str]],
     shell: Optional[bool] = None,
     cwd: Union[str, Path, None] = None,
+    virtualenv: Union[str, Path, None] = None,
     env: Optional[Mapping[str, str]] = None,
     append_path: Optional[Union[str, Path, List[Union[str, Path]], None]] = None,
     timeout: Optional[float] = None,
@@ -637,6 +679,7 @@ async def check_command_sterr(
         cmd,
         shell=shell,
         cwd=cwd,
+        virtualenv=virtualenv,
         env=env,
         append_path=append_path,
         timeout=timeout,
